#[non_exhaustive]pub enum KeyCopyBoundary {
NoSecretInput,
BorrowedCallerSecret,
ProviderCreatesSecret,
}Expand description
Secret-input copy behavior at the provider boundary.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoSecretInput
The operation has no secret-key input.
BorrowedCallerSecret
The provider borrows caller-owned secret bytes for the duration of one call.
ProviderCreatesSecret
The provider creates a new secret owner for the result.