#[non_exhaustive]pub enum KeyResidency {
ProcessMemory,
}Expand description
Residency of secret key material used by this dispatch package.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ProcessMemory
Secret material resides in caller or provider process memory.