#[non_exhaustive]pub enum ProviderPolicyReason {
SelectedCompiledImplementation,
RejectedOperationMismatch,
RejectedFeatureDisabled,
}Expand description
Fixed provider-policy reason recorded for a decision.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SelectedCompiledImplementation
The requested operation and algorithm are supported in the compiled lane.
RejectedOperationMismatch
The algorithm does not implement the requested operation family.
RejectedFeatureDisabled
The matching implementation was not compiled into this package.