Runtime dispatch entry points for sign/verify, key agreement, and KEM.
Functions
- derive_
keypair - Reconstruct a raw keypair for the given algorithm from existing secret material.
- derive_
shared_ secret - Derive a Diffie–Hellman shared secret. The returned secret zeroizes on drop.
- generate_
keypair - Generate a raw keypair for the given algorithm.
- kem_
decapsulate - Decapsulate a KEM ciphertext. The returned shared secret zeroizes on drop.
- kem_
encapsulate - Returns (shared_secret, ciphertext); the shared secret zeroizes on drop.
- sign
- Sign
msgwithsecretunder the selected signature algorithm, returning the detached signature bytes. - verify
- Verify a detached signature.